___   __         ___         ___            
  ___ _ / _ \ / /  ___   / _ ) ___ _ / _ \ ___  __ __
 / _ `// // // _ \/ -_) / _  |/ _ `// // // _ \ \ \ /
 \_,_//____//_//_/\__/ /____/ \_,_/ \___//_//_//_\_\ 

Jumat, 21 Oktober 2011

Cara membuat icon yahoo di blog

Cara buatnya sangat gampang kamu tinggal copy script berikut ini trus kamu pasang di sidebar kamu, udah tahu kan cara pasanganya Pertama kamu login ke blog kamu dulu. Terus pergi kerancangan ( page element) Add a Gadget Langsung ke HTML / Java Script dan masukan kode di bawah ini...
<a href="ymsgr:sendIM?adhebaonx"> <img src="http://opi.yahoo.com/online?u=adhebaonx&amp;m=g&amp;t=2&amp;l=us"/> </a>
dan kalo dah selesai kamu simpan. Ganti text yang warna merah (adhebaonx) dengan ID YAHOO (username) kamu. perhatikan angka "2", itu bisa kamu ganti dengan angka yang lain dan hasilnya gambar yang ditampilkan akan berbeda-beda. link asli http://web.gallerydunia.com/2
»»  READMORE ==>>

membuat chat box di blog

yang pertama tama musti anda lakukan adalah kunjungi situs yang ini dulu silahkan di klik shoutmix.com,
setelah anda klik link tersebut lalu anda akan di hadapkan ke halaman register/pendaftaran dan masukan data anda sesuai dengan yang di ingan kan di form tersebut...
yaitu di kolom yang pertama dari atas silahkan nama username anda (terserah anda)
setelah itu di kolom kedua silahkan isikan pasword yang ingin anda pakai untuk login,
kemudian di kolom yang ketiga masukkan ferifikasi pasword yang anda masukkan tadi di kolom yang kedua (inget! pasword harus sama dengan yang anda isikan di kolom yang kedua tadi), kemudian di kolom yang ke empat silahkan masukkan nama asli anda, dan yang terakhir masukkan alamat email yang anda punya.
nah..setelah anda lengkap mengisi data diri anda termasuk user name dan pasword lalu jangan lupa anda mengasih tanda centang atau cecklist pada tulisan " I have read and agree to the Terms of Service." setelah itu tekan tombol "continue".
setelah anda tadi tetrdaftar dan anda sekarang ada di halaman pemilihan style chat box.
anda bisa memilih style sesuka hati anda dengan cara kasih tanda titik atau cecklist pada style chat box anda pilih,
setelah itu masukkan ferisikasi kata yang ada di gambar sebelah kanan kolom. setelah itu anda klik "continue" selesai...
dan tahap selanjutnya adalah pengambilan code scriptnya..
yaitu dengan cara klik menu di paling atas yang bertuliskan " settings ", di dalam halam seting ini anda bisa mengkonfigurasi setingan chat box anda,
seperti mengubah warna chat box, dan lain2..
nah untuk mengkonfigurasi setingan ini anda bisa lakukan sendiri mendatang ( saya yakin anda bisa, dulu saya juga pas pertama juga binun.. heheh ) dan yang paling penting adalah tahap pengambilan code scriptnya..
setelah anda di halaman setting anda cari aja tulisan " Get codes " yang berada di kotak sebelah kiri atas (klik aja tulisan itu) anda akan dihalaman baru dan cari dan klik lagi yang bertuliskan " Place shoutbox on webpage "
setelah itu muculah code scriptnya di bawah... dan silahkan copy code script tersebut dan pastekan di halaman blog anda... ,
mengenai penempatan nya sesuai dengan selera anda.. dan yang paling baik di tempatkan di bagian "sidebar" blog anda..
cara menempatkan di sidebar pun cukup mudah, anda tinggal login ke bloggersetelah itu tekan menu di blogger yg bertuliskan "layout" abis ntu pilih lagi pilihan " Add a Page Element " ( pengaturan dalam bahasa inggris,
jika blog anda memakai pengaturan bahasa indonesia silahkan di kira2 sendir arti yang sama dengan kata " Add a Page Element "),
kemudian akan muncul jendela baru dan pilih lagi pilihan " HTML/JAVASCRIPT " dan masukkan code script chat box tadi ke kolom yang tersedia dan tekan tombolo save/simpan...
selesai sudah,


link aslinya http://master-blog-ayiek.blogspot.com
»»  READMORE ==>>

Kamis, 20 Oktober 2011

cara mempercepat Mozilla Firefox

asalamualaikum wr wb ni ane mo share.. bgaimna cara mempercepat mozila firefox mudah" berguna :D Langsung aja lah tanpa bnyak basa basi... 1 Buka Mozilla. 2 Ketikan di addres bar “about:config” (tanpa tanda patik). 3 Scroll mouse anda kebawah dan cari “network.http.max-connections“, double klik dan masukan nilai “64“. 4 Cari “network.http.max-connections-per-server“, double klik dan masukan nilai “21“. 5 Cari ‘network.http.max-persistent-connections-per-server“, double klik dan masukan nilai “8“. 6 Doube klik pada “network.http.pipelining ” menjadi “true“. 7 Cari “network.http.pipelining.maxrequests“, double klik dan masukan nilai “100“. 8 Double klik pada “network.http.proxy.pipelining” menjadi “true“. 9 Langkah terakhir, klik kanan dimana saja pilih : New >> integrar >> lalu tulis “nglayout.initialpaint.delay” (tanpa tanda petik”. Kemudian masukan nilai “ 0 “. mudah"n berguna sekian n terima kasih wasalamu alaikum wr wb...
»»  READMORE ==>>

Jumat, 15 Juli 2011

Drok google

inurl:"/NSearch/AdminServlet"
inurl:"/slxweb.dll/external?name=(custportal|webticketcust)"
inurl:":10000" intext:webmin
inurl:":10000" intext:webmin
inurl:"1220/parse_xml.cgi?"
inurl:"631/admin" (inurl:"op=*") | (intitle:CUPS)
inurl:"8003/Display?what="
inurl:"Activex/default.htm" "Demo"
inurl:"auth_user_file.txt"
inurl:"bookmark.htm"
inurl:"cacti" +inurl:"graph_view.php" +"Settings Tree View" -cvs -RPM
inurl:"calendar.asp?action=login"
inurl:"calendarscript/users.txt"
inurl:"default/login.php" intitle:"kerio"
inurl:"editor/list.asp" | inurl:"database_editor.asp" | inurl:"login.asa" "are set"
inurl:"GRC.DAT" intext:"password"
inurl:"GRC.DAT" intext:"password"
inurl:"gs/adminlogin.aspx"
inurl:"index.php? module=ew_filemanager"
inurl:"install/install.php"
inurl:"map.asp?" intitle:"WhatsUp Gold"
inurl:"newsletter/admin/"
inurl:"newsletter/admin/" intitle:"newsletter admin"
inurl:"NmConsole/Login.asp" | intitle:"Login - Ipswitch WhatsUp Professional 2005" | intext:"Ipswitch WhatsUp Professional 2005 (SP1)" "Ipswitch, Inc"
inurl:"php121login.php"
inurl:"printer/main.html" intext:"settings"
inurl:"putty.reg"
inurl:"Sites.dat"+"PASS="
inurl:"sitescope.html" intitle:"sitescope" intext:"refresh" -demo
inurl:"slapd.conf" intext:"credentials" -manpage -"Manual Page" -man: -sample
inurl:"slapd.conf" intext:"credentials" -manpage -"Manual Page" -man: -sample
inurl:"slapd.conf" intext:"rootpw" -manpage -"Manual Page" -man: -sample
inurl:"slapd.conf" intext:"rootpw" -manpage -"Manual Page" -man: -sample
inurl:"smb.conf" intext:"workgroup" filetype:conf conf
inurl:"suse/login.pl"
inurl:"typo3/index.php?u=" -demo
inurl:"usysinfo?login=true"
inurl:"utilities/TreeView.asp"
inurl:"ViewerFrame?Mode="
inurl:"ViewerFrame?Mode="
inurl:"ViewerFrame?Mode="
inurl:"ViewerFrame?Mode="
inurl:"vsadmin/login" | inurl:"vsadmin/admin" inurl:.php|.asp
inurl:"wvdial.conf" intext:"password"
inurl:"wvdial.conf" intext:"password"
inurl:"wwwroot/
inurl:*db filetype:mdb
inurl:/_layouts/settings
inurl:/adm-cfgedit.php
inurl:/admin/login.asp
inurl:/cgi-bin/finger? "In real life"
inurl:/cgi-bin/finger? Enter (account|host|user|username)
inurl:/cgi-bin/pass.txt
inurl:/cgi-bin/sqwebmail?noframes=1
inurl:/Citrix/Nfuse17/
inurl:/Citrix/Nfuse17/
inurl:/counter/index.php intitle:"+PHPCounter 7.*"
inurl:/dana-na/auth/welcome.html
inurl:/db/main.mdb
inurl:/db/main.mdb
inurl:/eprise/
inurl:/Merchant2/admin.mv | inurl:/Merchant2/admin.mvc | intitle:"Miva Merchant Administration Login" -inurl:cheap-malboro.net
inurl:/modcp/ intext:Moderator+vBulletin
inurl:/SUSAdmin intitle:"Microsoft Software Update Services"
inurl:/webedit.* intext:WebEdit Professional -html
inurl:/wwwboard
inurl:/wwwboard
inurl:/yabb/Members/Admin.dat
inurl::2082/frontend -demo
inurl:1810 "Oracle Enterprise Manager"
inurl:2000 intitle:RemotelyAnywhere -site:realvnc.com
inurl:access
inurl:admin filetype Big Grinb
inurl:admin filetype:xls
inurl:admin intitle:login
inurl:administrator "welcome to mambo"
inurl:aol*/_do/rss_popup?blogID=
inurl:asp
inurl:axis-cgi/jpg
inurl:axis-cgi/mjpg (motion-JPEG)
inurl:backup filetype:mdb
inurl:bin.welcome.sh | inurl:bin.welcome.bat | intitle:eHealth.5.0
inurl:build.err
inurl:buy
inurl:ccbill filetype:log
inurl:ccbill filetype:log
inurl:cgi
inurl:cgi-bin inurl:calendar.cfg
inurl:cgi-bin/printenv
inurl:cgi-bin/testcgi.exe "Please distribute TestCGI"
inurl:cgi-bin/ultimatebb.cgi?ubb=login
inurl:cgiirc.config
inurl:changepassword.asp
inurl:chap-secrets -cvs
inurl:Citrix/MetaFrame/default/default.aspx
inurl:config.php dbuname dbpass
inurl:config.php dbuname dbpass
inurl:confixx inurl:login|anmeldung
inurl:coranto.cgi intitle:Login (Authorized Users Only)
inurl:CrazyWWWBoard.cgi intext:"detailed debugging information"
inurl:csCreatePro.cgi
inurl: data
inurl:default.asp intitle:"WebCommander"
inurl:default.asp intitle:"WebCommander"
inurl:download
inurlBig Grins.py
inurl:email filetype:mdb
inurl:exchweb/bin/auth/owalogon.asp
inurl:fcgi-bin/echo
inurl:file
inurl:filezilla.xml -cvs
inurl:filezilla.xml -cvs
inurl:footer.inc.php
inurl:forum
inurl:forum filetype:mdb
inurl:forward filetype:forward -cvs
inurl:getmsg.html intitle:hotmail
inurl:gnatsweb.pl
inurl:home
inurl:hp/device/this.LCDispatcher
inurl:html
inurl:htpasswd filetype:htpasswd
inurl:ids5web
inurl:iisadmin
inurl:inc
inurl:indexFrame.shtml Axis
inurl:info
inurl:info.inc.php
inurl:irc filetype:cgi cgi:irc
inurl:lilo.conf filetype:conf password -tatercounter2000 -bootpwd -man
inurl:lilo.conf filetype:conf password -tatercounter2000 -bootpwd -man
inurl:list
inurl:log.nsf -gov
inurl:login filetype:swf swf
inurl:login filetype:swf swf
inurl:login.asp
inurl:login.cfm
inurl:login.jsp.bak
inurl:login.php "SquirrelMail version"
inurl:mail
inurl:main.php phpMyAdmin
inurl:main.php Welcome to phpMyAdmin
inurl:ManyServers.htm
inurl:metaframexp/default/login.asp | intitle:"Metaframe XP Login"
inurl:mewebmail
inurl:midicart.mdb
inurl:names.nsf?opendatabase
inurl:names.nsf?opendatabase
inurl:netscape.hst
inurl:netscape.hst
inurl:netscape.ini
inurl:netw_tcp.shtml
inurl:new
inurl:newsdesk.cgi? inurl:"t="
inurl:nuke filetype:sql
inurl:nuke filetype:sql
inurl:order
inurl:ospfd.conf intext:password -sample -test -tutorial -download
inurl:pages
inurl:pap-secrets -cvs
inurl:passlist.txt
inurl:passlist.txt
inurl:Proxy.txt
inurl:public
inurl:report "EVEREST Home Edition "
inurl:rpSys.html
inurl:search
inurl:search.php vbulletin
inurl:search/admin.php
inurl:secring ext:skr | ext:pgp | ext:bak
inurl:secring ext:skr | extgp | ext:bak
inurl:server.cfg rcon password
inurl:server-info "Apache Server Information"
inurl:server-status "apache"
inurl:servlet/webacc
inurl:shop
inurl:shopdbtest.asp
inurl:snitz_forums_2000.mdb
inurl:software
inurl:ssl.conf filetype:conf
inurl:statrep.nsf -gov
inurl:status.cgi?host=all
inurl:support
inurl:tdbin
inurl:testcgi xitami
inurl:textpattern/index.php
inurl:user
inurl:vbstats.php "page generated"
inurl:ventrilo_srv.ini adminpassword
inurl:view/index.shtml
inurl:view/indexFrame.shtml
inurl:view/view.shtml
inurl:ViewerFrame?Mode=Refresh
inurl:vtund.conf intext:pass -cvs s
inurl:vtund.conf intextass -cvs
inurl:WCP_USER
inurl:web
inurl:webalizer filetypeng -.gov -.edu -.mil -opendarwin
inurl:webmail./index.pl "Interface"
inurl:webutil.pl
inurl:webvpn.html "login" "Please enter your"
inurl:wp-mail.php + "There doesn't seem to be any new mail."
inurl:XcCDONTS.asp
inurl:yapboz_detay.asp
inurl:zebra.conf intext:password -sample -test -tutorial -download
inurl:zebra.conf intextassword -sample -test -tutorial -download
inurlap-secrets -cvs
inurlass.dat
inurlcw_login_username
inurldbc.ini ext:ini -cvs
inurlerform filetype:ini
inurlerform.ini filetype:ini
inurlerl/printenv
inurlhp.ini filetype:ini
inurlhpSysInfo/ "created by phpsysinfo"
inurlls/admin_/gateway.htm
inurlortscan.php "from Port"|"Port Range"
inurlostfixadmin intitle:"postfix admin" exthp
inurlrasso.wwsso_app_admin.ls_login
inurlreferences.ini "[emule]"
inurlrofiles filetype:mdb
inurlroxy | inurl:wpad extac | ext:dat findproxyforurl
inurlspfd.conf intextassword -sample -test -tutorial -download
inurlvcgi/jovw
ipsec.conf
ipsec.secrets
ipsec.secrets
Jetbox One CMS ?" | "
Jetstream ? *")
LeapFTP intitle:"index.of./" sites.ini modified
LeapFTP intitle:"index.of./" sites.ini modified
Link Department"
liveapplet
liveice configuration file ext:cfg
Login - Sun Cobalt RaQ
Login ("
Looking Glass
Lotus Domino address books
mail filetype:csv -site:gov intext:name
master.passwd
Mecury Version "Infastructure Group"
Merak Mail Server Software" -.gov -.mil -.edu -site:merakmailserver.com
Microsoft ® Windows * ™ Version * DrWtsn32 Copyright © ext:log
Microsoft Money Data Files
Midmart Messageboard" "Administrator Login"
Monster Top List" MTL numrange:200-
More Info about MetaCart Free
Most Submitted Forms and Scripts "this section"
mt-db-pass.cgi files
mysql dump filetype:sql
MYSQL error message: supplied argument....
mySQL error with query
mysql error with query
mysql history files
MySQL tabledata dumps
mystuff.xml - Trillian data files
natterchat inurl:home.asp -site:natterchat.co.uk
Netscape Application Server Error page
Network Vulnerability Assessment Report
NickServ registration passwords
not for distribution confidential
Novell NetWare intext:"netware management portal version"
ORA-00921: unexpected end of SQL command
ORA-00921: unexpected end of SQL command
ORA-00921: unexpected end of SQL command
ORA-00921: unexpected end of SQL command
ORA-00933: SQL command not properly ended
ORA-00936: missing expression
ORA-00936: missing expression
Outlook Web Access (a better way)
OWA Public Folders (direct view)
parent directory /appz/ -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
parent directory DVDRip -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
parent directory Gamez -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
parent directory MP3 -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
parent directory Name of Singer or album -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
parent directory Xvid -xxx -html -htm -php -shtml -opendivx -md5 -md5sums
passlist
passlist.txt (a better way)
passwd
passwd / etc (reliable)
pcANYWHERE EXPRESS Java Client
people.lst
Peoples MSN contact lists
phone * * * "address *" "e-mail" intitle:"curriculum vitae"
PhotoPost PHP Upload
PHP application warnings failing "include_path"
php-addressbook "This is the addressbook for *" -warning
PHPhotoalbum Statistics
PHPhotoalbum Upload
phpinfo()
phpMyAdmin "running on" inurl:"main.php"
phpMyAdmin dumps
phpMyAdmin dumps
phpMyAdmin MySQL-Dump "INSERT INTO" -"the"
phpMyAdmin MySQL-Dump filetype:txt
phpOpenTracker" Statistics
phpWebMail
Please enter a valid password! inurlolladmin
PostgreSQL query failed: ERROR: parser: parse error
POWERED BY HIT JAMMER 1.0!
Powered by mnoGoSearch - free web search engine software
powered by openbsd +"powered by apache"
Powered by UebiMiau -site:sourceforge.net
private key files (.csr)
private key files (.key)
produced by getstats
psyBNC config files
pwd.db
Quicken data files
Quote:
rdbqds -site:.edu -site:.mil -site:.gov
RedKernel"
Request Details "Control Tree" "Server Variables"
robots.txt
robots.txt "Disallow:" filetype:txt
Running in Child mode
server-dbs "intitle:index of"
sets mode: +k
sets mode: +p
sets mode: +s
signin filetype:url
signin filetype:url
site:edu admin grades
site:netcraft.com intitle:That.Site.Running Apache
site:ups.com intitle:"Ups Package tracking" intext:"1Z ### ### ## #### ### #"
site:www.mailinator.com inurl:ShowMail.do
sitebuildercontent
sitebuilderfiles
sitebuilderpictures
-sitehp.net -"The PHP Group" inurl:source inurl:url extHp
Snitz! forums db path error
spwd.db / passwd
SQL data dumps
SQL syntax error
Squid cache server reports
Supplied argument is not a valid MySQL result resource
Supplied argument is not a valid PostgreSQL result
Supplied argument is not a valid PostgreSQL result
Thank you for your order +receipt
This is a Shareaza Node
This report was generated by WebLog
This summary was generated by wwwstat
top secret site:mil
trillian.ini
UBB.threads")|(inurl:login.php "ubb")
UebiMiau" -site:sourceforge.net
Ultima Online loginservers
Ultima Online loginservers
Ultima Online loginservers
Unreal IRCd
VNC Desktop inurl:5800
VP-ASP Shop Administrators only
warning "error on line" php sablotron
Warning: Cannot modify header information - headers already sent
Web File Browser "Use regular expression"
Web Wiz Journal"
WebLog Referrers
Welcome to ntop!
Windows 2000 web server error messages
W-Nailer Upload Area
wwwboard WebAdmin inurlasswd.txt wwwboard|webadmin
WWWThreads")|(inurl:"wwwthreads/login.php")|(inurl:"wwwthreads/login.pl?Cat=")
XAMPP "inurl:xampp/index"
"xampp/phpinfo
You have an error in your SQL syntax near"""
XOOPS Custom Installation
Your password is * Remember this for later use
=+"HSTSNR" -"netop.com"
»»  READMORE ==>>

Senin, 18 April 2011

cara mengganti proxy sesuka hati

Pertama
agan mesti punya software yang namanya Proxy Finder Enterprise, untuk mengunduhnya silahken menuju link berikut :
http://www.ziddu.com/download/5681388/ProxyFinderEnterprisev2.5.rar.html

Setelah software tersebut diunduh silahken diinstall. Jangan lupa copy-paste cracknya ke folder instalansinya di drive C or C:\Program Files\ProxyFinderEnterprise. Jangan di jalankan dulu sebelum cracknya dicopy-paste. Setelah di copypaste baru jalankan softwarenya.

Trus kalo udah kebuka klik tombol find, tunggu aja mpe semua ter-search dengan baik dan benar. Hehehehehe Kalo loadingnya udah berhenti, pilih tombol save dan nyimpannya di desktop aja biar gampang nyarinya. Hehehehehe

Pasti buuuaaannnyyyaaakkk banget kan proxy-nya. Hehehehehe

Kedua
Setelah selesai tahap pertama tadi, sekarang saatnya buat nyeleksi proxy tersebut. Ingeet itu proxy gak semuanya aktif, jadi mesti diseleksi, kalo nyeleksinya satu-satu, yaa mampus lah, hahahahaha mrgreen

Saatnya kita gunakan tool online gratisan buat ngecek aktif atau tidaknya suatu proxy tadi. Silahken sampeyan menuju link berikut : http://www.checker.freeproxy.ru/checker/ dan copy-paste sebagian (kira-kira 30-50 proxy + port nya) ke dalam kotak pengecekkannya. Hehehehehe mrgreen Dengan format xxx.xxx.x.xx:yyyy (x=IP, y=port). Misalnya : 169.235.24.232:3127

Oiya daftar/list dari proxy tadi kan udah di save, buka aja filenya pake notepad trus copy-paste deh. mrgreen

Pada bagian time out pilih 5 (default angka 20 delete aja), trus pada bagian proxy type pilih All proxy types. Terakhir tekan tombol check proxy.

Tunggu mpe loadingnya selesai. Semakin banyak proxy yang dicopy-paste, makin lama juga nunggunya. Kalo dah selesai, tinggal scroll aja ke bawah, liat proxy yang working dan ada tulisan Proxy is high anonymous (elite) or Proxy is anonymous, yang itu aja yang dipake. Ok

Kalo udah diaplikasikan, silahken aja cek di tool online buat ngecek IP Address, misalnya di http://www.ip-adress.com/, http://www.checkip.org/, atau di http://whatismyipaddress.com/
Selanjutnya terserah anda.... Wkwkwkwkwkw asal jangan dipake buat macam-macam aja. Kalo terpaksa untuk macam-macam, agan mesti gunakan yang elite, jangan yang biasa. Ntar mampus lo. Hehehehe
»»  READMORE ==>>

Sabtu, 16 April 2011

List Crack password Online (tools)

»»  READMORE ==>>

Senin, 11 April 2011

Hacking Facebook, Twitter, etc Account

cara hacking facebook yang akan saya tulis ini adalah dengan menggunakan
addons FIRESHEEP. Firesheep merupakan add-on firefox yang bisa
digunakan untuk hacking facebook. Firesheep ini buatan Eric Butler,
seorang freelance web aplikasi dan pengembang perangkat lunak.
Sebenarnya firesheep ini bertujuan untuk mengantisipasi kurangnya
keamanan user login dan cookie pada web-web populer seperti facebook.
Sebenarnya Firesheep bukan hanya digunakan untuk facebook saja tapi
banyak website populer lainnya seperti cookies dari Amazon.com,
Basecamp, bit.ly, Cisco, CNET, Dropbox, Enom, Evernote, Flickr, Github,
Google, HackerNews, Harvest, Windows Live, NY Times, Pivotal Tracker,
Slicehost, tumblr, Twitter, WordPress, Yahoo, Yelp

Firesheep ini merupakan software opensource yang bisa anda download di http://codebutler.github.com/firesheep/
dan jangan lupa bagi anda pengguna windows untuk memasang winpcap
terlebih dahulu. Setelah anda mendownload dan menginstall firesheep dan
anda sedang berselancar ria di jaringan wifi yang gratis misalnya di
cafe. maka akan muncul sebuah sidebar baru yang menampilkan user-user
yang sedang login ke sebuah web sebagai contoh adalah Facebook. Jika
pengguna wifi ada yang login ke facebook dan tampil di sidebar anda,
maka anda hanya butuh mengklik 2 kali dan anda sekarang bisa login
sebagai dia tanpa harus memasukkan username dan password lagi.

Untuk cara menggunakan firesheep, tinggal tekan Ctrl + Shift + S pada
keyboard. maka secara otomatis akan muncul Sidebar di firefox anda.
Kemudian klik tombol Start Capturing. Jika berhasil, maka akan muncul
beberapa facebook orang-orang yang sedang online di kawasan hotspot
anda.



untuk mengantisipasinya tinggal kita gunakan backsheep..
kebalikan dari firesheep fungsinya.. silahkan di mengerti

dengan adanya tutorial ini semoga muncul kesadaran bahwa sebenarnya
hacking itu luas dan yang terpenting adalah proses dan ilmu yang kalian
dapatkan.. majulah "undergrond" Indonesia dan majulah IT indonesia

sekian dari saya,
»»  READMORE ==>>

IT indonesia